## Build
* kernel: {{ build.metadata.make_kernelversion }}
* git: {{ build.metadata.git_repo }}
* git branch: {{ build.metadata.git_branch }}
* git commit: {{ build.metadata.git_commit }}
* git describe: {{ build.version }}
* test details: {{ build_url }}

